import { AfterViewInit, EventEmitter, PipeTransform } from '@angular/core';
import { ChangeDetectorRef, ElementRef, OnDestroy } from '@angular/core';
import { IButtonGroupEventArgs } from '../buttonGroup/buttonGroup.component';
import { DisplayDensityBase, IDisplayDensityOptions } from '../core/density';
import { IQueryBuilderResourceStrings } from '../core/i18n/query-builder-resources';
import { PlatformUtil } from '../core/utils';
import { FilteringLogic, IFilteringExpression } from '../data-operations/filtering-expression.interface';
import { IExpressionTree } from '../data-operations/filtering-expressions-tree';
import { IgxOverlayOutletDirective } from '../directives/toggle/toggle.directive';
import { FieldType } from '../grids/common/grid.interface';
import { IgxIconService } from '../icon/icon.service';
import { OverlaySettings } from '../services/overlay/utilities';
import { IgxQueryBuilderHeaderComponent } from './query-builder-header.component';
import * as i0 from "@angular/core";
export declare class IgxFieldFormatterPipe implements PipeTransform {
    transform(value: any, formatter: (v: any, data: any, fieldData?: any) => any, rowData: any, fieldData?: any): any;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgxFieldFormatterPipe, never>;
    static ɵpipe: i0.ɵɵPipeDeclaration<IgxFieldFormatterPipe, "fieldFormatter", true>;
}
/**
 * @hidden @internal
 *
 * Internal class usage
 */
declare class ExpressionItem {
    parent: ExpressionGroupItem;
    selected: boolean;
    constructor(parent?: ExpressionGroupItem);
}
/**
 * @hidden @internal
 *
 * Internal class usage
 */
declare class ExpressionGroupItem extends ExpressionItem {
    operator: FilteringLogic;
    children: ExpressionItem[];
    constructor(operator: FilteringLogic, parent?: ExpressionGroupItem);
}
/**
 * @hidden @internal
 *
 * Internal class usage
 */
declare class ExpressionOperandItem extends ExpressionItem {
    expression: IFilteringExpression;
    inEditMode: boolean;
    inAddMode: boolean;
    hovered: boolean;
    fieldLabel: string;
    constructor(expression: IFilteringExpression, parent: ExpressionGroupItem);
}
/**
 * A component used for operating with complex filters by creating or editing conditions
 * and grouping them using AND/OR logic.
 * It is used internally in the Advanced Filtering of the Grid.
 *
 * @example
 * ```html
 * <igx-query-builder [fields]="this.fields">
 * </igx-query-builder>
 * ```
 */
export declare class IgxQueryBuilderComponent extends DisplayDensityBase implements AfterViewInit, OnDestroy {
    cdr: ChangeDetectorRef;
    protected iconService: IgxIconService;
    protected platform: PlatformUtil;
    protected el: ElementRef;
    protected _localeId: string;
    protected _displayDensityOptions?: IDisplayDensityOptions;
    /**
     * @hidden @internal
     */
    cssClass: string;
    /**
     * @hidden @internal
     */
    display: string;
    /**
    * Returns the fields.
    */
    get fields(): FieldType[];
    /**
     * Sets the fields.
     */
    set fields(fields: FieldType[]);
    /**
    * Returns the expression tree.
    */
    get expressionTree(): IExpressionTree;
    /**
     * Sets the expression tree.
     */
    set expressionTree(expressionTree: IExpressionTree);
    /**
     * Gets the `locale` of the query builder.
     * If not set, defaults to application's locale.
     */
    get locale(): string;
    /**
     * Sets the `locale` of the query builder.
     * Expects a valid BCP 47 language tag.
     */
    set locale(value: string);
    /**
     * Sets the resource strings.
     * By default it uses EN resources.
     */
    set resourceStrings(value: IQueryBuilderResourceStrings);
    /**
     * Returns the resource strings.
     */
    get resourceStrings(): IQueryBuilderResourceStrings;
    /**
     * Event fired as the expression tree is changed.
     *
     * ```html
     *  <igx-query-builder (expressionTreeChange)='onExpressionTreeChange()'></igx-query-builder>
     * ```
     */
    expressionTreeChange: EventEmitter<any>;
    private fieldSelect;
    private conditionSelect;
    private searchValueInput;
    private picker;
    private addRootAndGroupButton;
    private addConditionButton;
    /**
     * @hidden @internal
     */
    headerContent: IgxQueryBuilderHeaderComponent;
    protected set editingInputsContainer(value: ElementRef);
    /** @hidden */
    protected get editingInputsContainer(): ElementRef;
    protected set addModeContainer(value: ElementRef);
    /** @hidden */
    protected get addModeContainer(): ElementRef;
    protected set currentGroupButtonsContainer(value: ElementRef);
    /** @hidden */
    protected get currentGroupButtonsContainer(): ElementRef;
    private contextMenuToggle;
    private chips;
    private expressionsContainer;
    private overlayOutlet;
    /**
     * @hidden @internal
     */
    rootGroup: ExpressionGroupItem;
    /**
     * @hidden @internal
     */
    selectedExpressions: ExpressionOperandItem[];
    /**
     * @hidden @internal
     */
    currentGroup: ExpressionGroupItem;
    /**
     * @hidden @internal
     */
    contextualGroup: ExpressionGroupItem;
    /**
     * @hidden @internal
     */
    filteringLogics: any;
    /**
     * @hidden @internal
     */
    selectedCondition: string;
    /**
     * @hidden @internal
     */
    searchValue: any;
    /**
     * @hidden @internal
     */
    pickerOutlet: IgxOverlayOutletDirective | ElementRef;
    /**
     * @hidden @internal
     */
    fieldSelectOverlaySettings: OverlaySettings;
    /**
     * @hidden @internal
     */
    conditionSelectOverlaySettings: OverlaySettings;
    private destroy$;
    private _selectedField;
    private _clickTimer;
    private _dblClickDelay;
    private _preventChipClick;
    private _editingInputsContainer;
    private _addModeContainer;
    private _currentGroupButtonsContainer;
    private _addModeExpression;
    private _editedExpression;
    private _selectedGroups;
    private _fields;
    private _expressionTree;
    private _locale;
    private _resourceStrings;
    private _positionSettings;
    private _overlaySettings;
    constructor(cdr: ChangeDetectorRef, iconService: IgxIconService, platform: PlatformUtil, el: ElementRef, _localeId: string, _displayDensityOptions?: IDisplayDensityOptions);
    /**
     * @hidden @internal
     */
    ngAfterViewInit(): void;
    /**
     * @hidden @internal
     */
    ngOnDestroy(): void;
    /**
     * @hidden @internal
     */
    set selectedField(value: FieldType);
    /**
     * @hidden @internal
     */
    get selectedField(): FieldType;
    /**
     * @hidden @internal
     *
     * used by the grid
     */
    setPickerOutlet(outlet?: IgxOverlayOutletDirective | ElementRef): void;
    /**
     * @hidden @internal
     *
     * used by the grid
     */
    get isContextMenuVisible(): boolean;
    /**
     * @hidden @internal
     */
    get hasEditedExpression(): boolean;
    /**
     * @hidden @internal
     */
    addCondition(parent: ExpressionGroupItem, afterExpression?: ExpressionItem): void;
    /**
     * @hidden @internal
     */
    addAndGroup(parent?: ExpressionGroupItem, afterExpression?: ExpressionItem): void;
    /**
     * @hidden @internal
     */
    addOrGroup(parent?: ExpressionGroupItem, afterExpression?: ExpressionItem): void;
    /**
     * @hidden @internal
     */
    endGroup(groupItem: ExpressionGroupItem): void;
    /**
     * @hidden @internal
     */
    commitOperandEdit(): void;
    /**
     * @hidden @internal
     */
    cancelOperandAdd(): void;
    /**
     * @hidden @internal
     */
    cancelOperandEdit(): void;
    /**
     * @hidden @internal
     */
    operandCanBeCommitted(): boolean;
    /**
     * @hidden @internal
     *
     * used by the grid
     */
    exitOperandEdit(): void;
    /**
     * @hidden @internal
     */
    isExpressionGroup(expression: ExpressionItem): boolean;
    /**
     * @hidden @internal
     */
    onChipRemove(expressionItem: ExpressionItem): void;
    /**
     * @hidden @internal
     */
    onChipClick(expressionItem: ExpressionOperandItem): void;
    /**
     * @hidden @internal
     */
    onChipDblClick(expressionItem: ExpressionOperandItem): void;
    /**
     * @hidden @internal
     */
    enterExpressionEdit(expressionItem: ExpressionOperandItem): void;
    /**
     * @hidden @internal
     */
    clearSelection(): void;
    /**
     * @hidden @internal
     */
    enterExpressionAdd(expressionItem: ExpressionOperandItem): void;
    /**
     * @hidden @internal
     */
    contextMenuClosed(): void;
    /**
     * @hidden @internal
     */
    onKeyDown(eventArgs: KeyboardEvent): void;
    /**
     * @hidden @internal
     */
    createAndGroup(): void;
    /**
     * @hidden @internal
     */
    createOrGroup(): void;
    /**
     * @hidden @internal
     */
    deleteFilters(): void;
    /**
     * @hidden @internal
     */
    onGroupClick(groupItem: ExpressionGroupItem): void;
    /**
     * @hidden @internal
     */
    ungroup(): void;
    /**
     * @hidden @internal
     */
    deleteGroup(): void;
    /**
     * @hidden @internal
     */
    selectFilteringLogic(event: IButtonGroupEventArgs): void;
    /**
     * @hidden @internal
     */
    getConditionFriendlyName(name: string): string;
    /**
     * @hidden @internal
     */
    isDate(value: any): boolean;
    /**
     * @hidden @internal
     */
    onExpressionsScrolled(): void;
    /**
     * @hidden @internal
     */
    invokeClick(eventArgs: KeyboardEvent): void;
    /**
     * @hidden @internal
     */
    openPicker(args: KeyboardEvent): void;
    /**
     * @hidden @internal
     */
    onOutletPointerDown(event: any): void;
    /**
     * @hidden @internal
     */
    getConditionList(): string[];
    /**
     * @hidden @internal
     */
    getFormatter(field: string): (value: any, rowData?: any) => any;
    /**
     * @hidden @internal
     */
    getFormat(field: string): string;
    /**
     * @hidden @internal
     *
     * used by the grid
     */
    setAddButtonFocus(): void;
    /**
     * @hidden @internal
     */
    context(expression: ExpressionItem, afterExpression?: ExpressionItem): {
        $implicit: ExpressionItem;
        afterExpression: ExpressionItem;
    };
    /**
     * @hidden @internal
     */
    onChipSelectionEnd(): void;
    private setFormat;
    private setFilters;
    private onToggleExpression;
    private toggleExpression;
    private addGroup;
    private createExpressionGroupItem;
    private createExpressionTreeFromGroupItem;
    private toggleContextMenu;
    private findSingleSelectedGroup;
    private isInsideGroup;
    private deleteItem;
    private createGroup;
    private toggleGroup;
    private toggleGroupRecursive;
    private deselectParentRecursive;
    private calculateContextMenuTarget;
    private scrollElementIntoView;
    private init;
    private registerSVGIcons;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgxQueryBuilderComponent, [null, null, null, null, null, { optional: true; }]>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgxQueryBuilderComponent, "igx-query-builder", never, { "fields": { "alias": "fields"; "required": false; }; "expressionTree": { "alias": "expressionTree"; "required": false; }; "locale": { "alias": "locale"; "required": false; }; "resourceStrings": { "alias": "resourceStrings"; "required": false; }; }, { "expressionTreeChange": "expressionTreeChange"; }, ["headerContent"], ["igx-query-builder-header"], true, never>;
}
export {};
